API Documentation
=================


Generated Classes
-----------------

Classes generated using ``python_jsonschema_objects`` expose all defined
properties as both attributes and through dictionary access.

In addition, classes contain a number of utility methods for serialization,
deserialization, and validation.

.. autoclass:: python_jsonschema_objects.classbuilder.ProtocolBase
    :members:
